@@ -1,6 +1,6 @@
 # coding: utf-8
 import redis
-from redis._compat import urlparse
+from urllib.parse import urlparse
 import logging
 
 logger = logging.getLogger(__name__)
